@@ -116,7 +116,7 @@ class FreqDetectionResult:
     error_code_int: int
     error_code: str
     error_severity: str
-    error_message: str
+    error_message: str = ""
 
 
 class PreprocessError(Exception):
@@ -485,5 +485,5 @@ class ProphetDetector(BaseDetector):
                 self.anomalies = pd.DataFrame()
                 return self.anomalies
         except Exception as e:
-            self._logs.error(e, exc_info=True)
+            self._logs.error(e, exception=e)
             raise e
